@@ -83,6 +83,8 @@ PreviousMode="normal"
 SilentProfile=False
 PreviouseProfile="silent"
 
+UIStyle=""
+
 DelayStart=0
 interval=0
 #GraphStart=0
@@ -122,7 +124,8 @@ RecordFileSelectedDate=""
 MovementBarColor="#DFAD09" #"Yellow"
 #AlarmColor="Red"
 #AlarmTimeWindowColor="Orange"
-GraphBackground="#101010"
+GraphBackground="#000000"
+#GraphBackground="#101010"
 #some colors are also defined in functions_record.py
 
 FilterScale=40
